==> fary-1.0.14.tgz: package/src/index.ts <==
import log = require('fary-log');
import Koa = require('koa');
import koaCompress = require('koa-compress');
import koaLogger = require('koa-logger');
import errorMiddleware = require('./middlewares/error');
import proxyMiddleware = require('./middlewares/proxy');
import checkProxy = require('./utils/check-proxy');
import ENV = require('./utils/env');
import serverConfig = require('./utils/server-config');

import { IAppOptions, IServerConfig } from './types';

const { IS_DEV } = ENV;
const logger = log('fary:app');
const serverConfigValue = serverConfig.value;

const DEFAULT_OPTIONS = {
  middlewares: [],
};

/**
 * createApp
 * @param {Object} options - options
 * @param {Function} onStart - callback after server start
 * @return {Koa} app - serverApp
 */
function createApp(options: IAppOptions, onStart = () => void 0) {
  options = Object.assign({}, DEFAULT_OPTIONS, options);

  if (IS_DEV) {
    checkProxy(serverConfigValue.proxy);
  }

  logger.log(`Debug mode:`, IS_DEV);
  logger.log(`Proxy mapping:`, serverConfigValue.proxy);

  const app: Koa = new Koa();

  // trust proxy
  app.proxy = true;

  const middlewares = [
    // request/response log
    koaLogger(),
    // compress the response
    koaCompress(),
    // error handler
    errorMiddleware(),
    ...(options.middlewares as Koa.Middleware[]),
    // proxy handler
    proxyMiddleware(),
  ];

  middlewares.forEach((middleware: Koa.Middleware) => {
    if (!middleware) {
      return;
    }
    app.use(middleware);
  });

  app.on('error', (err: Error) => {
    logger.error(`Server error: \n ${err.stack}`);
  });

  app.listen(serverConfigValue.port, () => {
    logger.info(`Koa server is listening at ${serverConfigValue.port}`);
    onStart();
  });

  process.on('SIGINT', () => {
    process.exit();
  });

  return app;
}

export = createApp;

==> fary-1.0.28.tgz: package/src/index.ts <==
import log = require('fary-log');
import Koa = require('koa');
import koaCompress = require('koa-compress');
import koaLogger = require('koa-logger');
import errorMiddleware = require('./middlewares/error');
import proxyMiddleware = require('./middlewares/proxy');
import checkProxy = require('./utils/check-proxy');
import ENV = require('./utils/env');
import serverConfig = require('./utils/server-config');

import { IAppOptions, IServerConfig } from './types';

const { IS_DEV } = ENV;
const logger = log('fary:app');

const DEFAULT_OPTIONS = {
  middlewares: [],
  skipListen: false,
};

/**
 * createApp
 * @param {Object} options - options
 * @param {Function} onStart - callback after server start
 * @return {Koa} app - serverApp
 */
// tslint:disable-next-line:no-empty
function createApp(options: IAppOptions, onStart = () => {}) {
  options = Object.assign({}, DEFAULT_OPTIONS, options);

  const proxyConfig = options.proxy || serverConfig.value.proxy;
  checkProxy(proxyConfig);

  logger.log(`Debug mode:`, IS_DEV);
  logger.log(`Proxy mapping:`, proxyConfig);

  const app: Koa = new Koa();

  // trust proxy
  app.proxy = true;

  const middlewares = [
    // request/response log
    koaLogger(),
    // compress the response
    koaCompress(),
    // error handler
    errorMiddleware(),
    ...(options.middlewares as Koa.Middleware[]),
    // proxy handler
    proxyMiddleware(),
  ];

  middlewares.forEach((middleware: Koa.Middleware) => {
    if (!middleware) {
      return;
    }
    app.use(middleware);
  });

  app.on('error', (err: Error) => {
    logger.error(`Server error: \n ${err.stack}`);
  });

  if (!options.skipListen) {
    const port = options.port || serverConfig.value.port;
    app.listen(port, () => {
      logger.info(`Koa server is listening at ${port}`);
      onStart();
    });
  }

  process.on('SIGINT', () => {
    process.exit();
  });

  return app;
}

// tslint:disable-next-line:no-namespace
declare namespace createApp {}

export = createApp;
